{
  am_pm_abbreviated => [
    "Muhi",
    "Chilo",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "kde",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Ll3",
    "Ll4",
    "Ll5",
    "Ll6",
    "Ll7",
    "Ll1",
    "Ll2",
  ],
  day_format_narrow => [
    3,
    4,
    5,
    6,
    7,
    1,
    2,
  ],
  day_format_wide => [
    "Liduva lyatatu",
    "Liduva lyanchechi",
    "Liduva lyannyano",
    "Liduva lyannyano na linji",
    "Liduva lyannyano na mavili",
    "Liduva litandi",
    "Liduva lyapili",
  ],
  day_stand_alone_abbreviated => [
    "Ll3",
    "Ll4",
    "Ll5",
    "Ll6",
    "Ll7",
    "Ll1",
    "Ll2",
  ],
  day_stand_alone_narrow => [
    3,
    4,
    5,
    6,
    7,
    1,
    2,
  ],
  day_stand_alone_wide => [
    "Liduva lyatatu",
    "Liduva lyanchechi",
    "Liduva lyannyano",
    "Liduva lyannyano na linji",
    "Liduva lyannyano na mavili",
    "Liduva litandi",
    "Liduva lyapili",
  ],
  era_abbreviated => [
    "AY",
    "NY",
  ],
  era_narrow => [
    "AY",
    "NY",
  ],
  era_wide => [
    "Akanapawa Yesu",
    "Nankuida Yesu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Makonde",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mac",
    "Apr",
    "Mei",
    "Jun",
    "Jul",
    "Ago",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Mwedi Ntandi",
    "Mwedi wa Pili",
    "Mwedi wa Tatu",
    "Mwedi wa Nchechi",
    "Mwedi wa Nnyano",
    "Mwedi wa Nnyano na Umo",
    "Mwedi wa Nnyano na Mivili",
    "Mwedi wa Nnyano na Mitatu",
    "Mwedi wa Nnyano na Nchechi",
    "Mwedi wa Nnyano na Nnyano",
    "Mwedi wa Nnyano na Nnyano na U",
    "Mwedi wa Nnyano na Nnyano na M",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mac",
    "Apr",
    "Mei",
    "Jun",
    "Jul",
    "Ago",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Mwedi Ntandi",
    "Mwedi wa Pili",
    "Mwedi wa Tatu",
    "Mwedi wa Nchechi",
    "Mwedi wa Nnyano",
    "Mwedi wa Nnyano na Umo",
    "Mwedi wa Nnyano na Mivili",
    "Mwedi wa Nnyano na Mitatu",
    "Mwedi wa Nnyano na Nchechi",
    "Mwedi wa Nnyano na Nnyano",
    "Mwedi wa Nnyano na Nnyano na U",
    "Mwedi wa Nnyano na Nnyano na M",
  ],
  name => "Makonde",
  native_language => "Chimakonde",
  native_name => "Chimakonde",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "L1",
    "L2",
    "L3",
    "L4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Lobo 1",
    "Lobo 2",
    "Lobo 3",
    "Lobo 4",
  ],
  quarter_stand_alone_abbreviated => [
    "L1",
    "L2",
    "L3",
    "L4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Lobo 1",
    "Lobo 2",
    "Lobo 3",
    "Lobo 4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 38,
}
