{
  am_pm_abbreviated => [
    "OD",
    "OT",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "luo-KE",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "WUT",
    "TAR",
    "TAD",
    "TAN",
    "TAB",
    "NGS",
    "JMP",
  ],
  day_format_narrow => [
    "W",
    "T",
    "T",
    "T",
    "T",
    "N",
    "J",
  ],
  day_format_wide => [
    "Wuok Tich",
    "Tich Ariyo",
    "Tich Adek",
    "Tich Ang\N{U+2019}wen",
    "Tich Abich",
    "Ngeso",
    "Jumapil",
  ],
  day_stand_alone_abbreviated => [
    "WUT",
    "TAR",
    "TAD",
    "TAN",
    "TAB",
    "NGS",
    "JMP",
  ],
  day_stand_alone_narrow => [
    "W",
    "T",
    "T",
    "T",
    "T",
    "N",
    "J",
  ],
  day_stand_alone_wide => [
    "Wuok Tich",
    "Tich Ariyo",
    "Tich Adek",
    "Tich Ang\N{U+2019}wen",
    "Tich Abich",
    "Ngeso",
    "Jumapil",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Kapok Kristo obiro",
    "Ka Kristo osebiro",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Luo",
  month_format_abbreviated => [
    "DAC",
    "DAR",
    "DAD",
    "DAN",
    "DAH",
    "DAU",
    "DAO",
    "DAB",
    "DOC",
    "DAP",
    "DGI",
    "DAG",
  ],
  month_format_narrow => [
    "C",
    "R",
    "D",
    "N",
    "B",
    "U",
    "B",
    "B",
    "C",
    "P",
    "C",
    "P",
  ],
  month_format_wide => [
    "Dwe mar Achiel",
    "Dwe mar Ariyo",
    "Dwe mar Adek",
    "Dwe mar Ang\N{U+2019}wen",
    "Dwe mar Abich",
    "Dwe mar Auchiel",
    "Dwe mar Abiriyo",
    "Dwe mar Aboro",
    "Dwe mar Ochiko",
    "Dwe mar Apar",
    "Dwe mar gi achiel",
    "Dwe mar Apar gi ariyo",
  ],
  month_stand_alone_abbreviated => [
    "DAC",
    "DAR",
    "DAD",
    "DAN",
    "DAH",
    "DAU",
    "DAO",
    "DAB",
    "DOC",
    "DAP",
    "DGI",
    "DAG",
  ],
  month_stand_alone_narrow => [
    "C",
    "R",
    "D",
    "N",
    "B",
    "U",
    "B",
    "B",
    "C",
    "P",
    "C",
    "P",
  ],
  month_stand_alone_wide => [
    "Dwe mar Achiel",
    "Dwe mar Ariyo",
    "Dwe mar Adek",
    "Dwe mar Ang\N{U+2019}wen",
    "Dwe mar Abich",
    "Dwe mar Auchiel",
    "Dwe mar Abiriyo",
    "Dwe mar Aboro",
    "Dwe mar Ochiko",
    "Dwe mar Apar",
    "Dwe mar gi achiel",
    "Dwe mar Apar gi ariyo",
  ],
  name => "Luo Kenya",
  native_language => "Dholuo",
  native_name => "Dholuo Kenya",
  native_script => undef,
  native_territory => "Kenya",
  native_variant => undef,
  quarter_format_abbreviated => [
    "NMN1",
    "NMN2",
    "NMN3",
    "NMN4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "nus mar nus 1",
    "nus mar nus 2",
    "nus mar nus 3",
    "nus mar nus 4",
  ],
  quarter_stand_alone_abbreviated => [
    "NMN1",
    "NMN2",
    "NMN3",
    "NMN4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "nus mar nus 1",
    "nus mar nus 2",
    "nus mar nus 3",
    "nus mar nus 4",
  ],
  script => undef,
  territory => "Kenya",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 38,
}
