{
  am_pm_abbreviated => [
    "a.m.",
    "p.m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d-M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-one" => "'week' W 'van' MMMM",
    "MMMMW-count-other" => "'week' W 'van' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d-M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M-y",
    yMEd => "E d-M-y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d-M-y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'week' w 'in' Y",
    "yw-count-other" => "'week' w 'in' Y",
  },
  code => "nl-NL",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd-MM-y",
  datetime_format_full => "{1} 'om' {0}",
  datetime_format_long => "{1} 'om' {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "ma",
    "di",
    "wo",
    "do",
    "vr",
    "za",
    "zo",
  ],
  day_format_narrow => [
    "M",
    "D",
    "W",
    "D",
    "V",
    "Z",
    "Z",
  ],
  day_format_wide => [
    "maandag",
    "dinsdag",
    "woensdag",
    "donderdag",
    "vrijdag",
    "zaterdag",
    "zondag",
  ],
  day_stand_alone_abbreviated => [
    "ma",
    "di",
    "wo",
    "do",
    "vr",
    "za",
    "zo",
  ],
  day_stand_alone_narrow => [
    "M",
    "D",
    "W",
    "D",
    "V",
    "Z",
    "Z",
  ],
  day_stand_alone_wide => [
    "maandag",
    "dinsdag",
    "woensdag",
    "donderdag",
    "vrijdag",
    "zaterdag",
    "zondag",
  ],
  era_abbreviated => [
    "v.Chr.",
    "n.Chr.",
  ],
  era_narrow => [
    "v.C.",
    "n.C.",
  ],
  era_wide => [
    "voor Christus",
    "na Christus",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %e %b %Y %k:%M:%S %Z",
  glibc_date_format => "%d-%m-%y",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Dutch",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mrt.",
    "apr.",
    "mei",
    "jun.",
    "jul.",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "januari",
    "februari",
    "maart",
    "april",
    "mei",
    "juni",
    "juli",
    "augustus",
    "september",
    "oktober",
    "november",
    "december",
  ],
  month_stand_alone_abbreviated => [
    "jan.",
    "feb.",
    "mrt.",
    "apr.",
    "mei",
    "jun.",
    "jul.",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "januari",
    "februari",
    "maart",
    "april",
    "mei",
    "juni",
    "juli",
    "augustus",
    "september",
    "oktober",
    "november",
    "december",
  ],
  name => "Dutch Netherlands",
  native_language => "Nederlands",
  native_name => "Nederlands Nederland",
  native_script => undef,
  native_territory => "Nederland",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1e kwartaal",
    "2e kwartaal",
    "3e kwartaal",
    "4e kwartaal",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1e kwartaal",
    "2e kwartaal",
    "3e kwartaal",
    "4e kwartaal",
  ],
  script => undef,
  territory => "Netherlands",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 38,
}
