{
  am_pm_abbreviated => [
    "TO",
    "TK",
  ],
  available_formats => {
    Bh => "B h",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E, B h:mm",
    EBhms => "E, B h:mm:ss",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "d, E",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "G y",
    GyMMM => "MMM, G y",
    GyMMMEd => "E, d-MMM, G y",
    GyMMMd => "d-MMM, G y",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss (v)",
    Hmv => "HH:mm (v)",
    M => "LL",
    MEd => "E, dd/MM",
    MMM => "LLL",
    MMMEd => "E, d-MMM",
    "MMMMW-count-one" => "MMMM, W-'hafta'",
    "MMMMW-count-other" => "MMMM, W-'hafta'",
    MMMMd => "d-MMMM",
    MMMd => "d-MMM",
    Md => "dd/MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a (v)",
    hmv => "h:mm a (v)",
    ms => "mm:ss",
    y => "y",
    yM => "MM.y",
    yMEd => "E, dd/MM/y",
    yMMM => "MMM, y",
    yMMMEd => "E, d-MMM, y",
    yMMMM => "MMMM, y",
    yMMMd => "d-MMM, y",
    yMd => "dd/MM/y",
    yQQQ => "y, QQQ",
    yQQQQ => "y, QQQQ",
    "yw-count-one" => "Y, w-'hafta'",
    "yw-count-other" => "Y, w-'hafta'",
  },
  code => "uz",
  date_format_full => "EEEE, d-MMMM, y",
  date_format_long => "d-MMMM, y",
  date_format_medium => "d-MMM, y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Dush",
    "Sesh",
    "Chor",
    "Pay",
    "Jum",
    "Shan",
    "Yak",
  ],
  day_format_narrow => [
    "D",
    "S",
    "C",
    "P",
    "J",
    "S",
    "Y",
  ],
  day_format_wide => [
    "dushanba",
    "seshanba",
    "chorshanba",
    "payshanba",
    "juma",
    "shanba",
    "yakshanba",
  ],
  day_stand_alone_abbreviated => [
    "Dush",
    "Sesh",
    "Chor",
    "Pay",
    "Jum",
    "Shan",
    "Yak",
  ],
  day_stand_alone_narrow => [
    "D",
    "S",
    "C",
    "P",
    "J",
    "S",
    "Y",
  ],
  day_stand_alone_wide => [
    "dushanba",
    "seshanba",
    "chorshanba",
    "payshanba",
    "juma",
    "shanba",
    "yakshanba",
  ],
  era_abbreviated => [
    "m.a.",
    "milodiy",
  ],
  era_narrow => [
    "m.a.",
    "milodiy",
  ],
  era_wide => [
    "miloddan avvalgi",
    "milodiy",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Uzbek",
  month_format_abbreviated => [
    "yan",
    "fev",
    "mar",
    "apr",
    "may",
    "iyn",
    "iyl",
    "avg",
    "sen",
    "okt",
    "noy",
    "dek",
  ],
  month_format_narrow => [
    "Y",
    "F",
    "M",
    "A",
    "M",
    "I",
    "I",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "yanvar",
    "fevral",
    "mart",
    "aprel",
    "may",
    "iyun",
    "iyul",
    "avgust",
    "sentabr",
    "oktabr",
    "noyabr",
    "dekabr",
  ],
  month_stand_alone_abbreviated => [
    "Yan",
    "Fev",
    "Mar",
    "Apr",
    "May",
    "Iyn",
    "Iyl",
    "Avg",
    "Sen",
    "Okt",
    "Noy",
    "Dek",
  ],
  month_stand_alone_narrow => [
    "Y",
    "F",
    "M",
    "A",
    "M",
    "I",
    "I",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Yanvar",
    "Fevral",
    "Mart",
    "Aprel",
    "May",
    "Iyun",
    "Iyul",
    "Avgust",
    "Sentabr",
    "Oktabr",
    "Noyabr",
    "Dekabr",
  ],
  name => "Uzbek",
  native_language => "o\N{U+2018}zbek",
  native_name => "o\N{U+2018}zbek",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "1-ch",
    "2-ch",
    "3-ch",
    "4-ch",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1-chorak",
    "2-chorak",
    "3-chorak",
    "4-chorak",
  ],
  quarter_stand_alone_abbreviated => [
    "1-ch",
    "2-ch",
    "3-ch",
    "4-ch",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1-chorak",
    "2-chorak",
    "3-chorak",
    "4-chorak",
  ],
  script => undef,
  territory => undef,
  time_format_full => "H:mm:ss (zzzz)",
  time_format_long => "H:mm:ss (z)",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 38,
}
