{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "B h",
    Bhm => "B h:mm",
    Bhms => "B h:mm:ss",
    E => "ccc",
    EBhm => "E B h:mm",
    EBhms => "E B h:mm:ss",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y. 'urteko' MMM",
    GyMMMEd => "G y. 'urteko' MMM d, E",
    GyMMMd => "G y. 'urteko' MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "M/d, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "MMMM W. 'astea'",
    "MMMMW-count-other" => "MMMM W. 'astea'",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "y/M",
    yMEd => "y/M/d, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y('e')'ko' MMMM",
    yMMMMEd => "y('e')'ko' MMMM'k' d, E",
    yMMMMd => "y('e')'ko' MMMM'ren' d",
    yMMMd => "y MMM d",
    yMd => "y/M/d",
    yQQQ => "y('e')'ko' QQQ",
    yQQQQ => "y('e')'ko' QQQQ",
    "yw-count-one" => "Y. 'urteko' w. 'astea'",
    "yw-count-other" => "Y. 'urteko' w. 'astea'",
  },
  code => "eu-ES",
  date_format_full => "y('e')'ko' MMMM'ren' d('a'), EEEE",
  date_format_long => "y('e')'ko' MMMM'ren' d('a')",
  date_format_medium => "y('e')'ko' MMM d('a')",
  date_format_short => "yy/M/d",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "al.",
    "ar.",
    "az.",
    "og.",
    "or.",
    "lr.",
    "ig.",
  ],
  day_format_narrow => [
    "A",
    "A",
    "A",
    "O",
    "O",
    "L",
    "I",
  ],
  day_format_wide => [
    "astelehena",
    "asteartea",
    "asteazkena",
    "osteguna",
    "ostirala",
    "larunbata",
    "igandea",
  ],
  day_stand_alone_abbreviated => [
    "al.",
    "ar.",
    "az.",
    "og.",
    "or.",
    "lr.",
    "ig.",
  ],
  day_stand_alone_narrow => [
    "A",
    "A",
    "A",
    "O",
    "O",
    "L",
    "I",
  ],
  day_stand_alone_wide => [
    "astelehena",
    "asteartea",
    "asteazkena",
    "osteguna",
    "ostirala",
    "larunbata",
    "igandea",
  ],
  era_abbreviated => [
    "K.a.",
    "K.o.",
  ],
  era_narrow => [
    "K.a.",
    "K.o.",
  ],
  era_wide => [
    "K.a.",
    "Kristo ondoren",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%y-%m-%d %T %Z",
  glibc_date_format => "%a, %Y.eko %bren %da",
  glibc_datetime_format => "%y-%m-%d %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Basque",
  month_format_abbreviated => [
    "urt.",
    "ots.",
    "mar.",
    "api.",
    "mai.",
    "eka.",
    "uzt.",
    "abu.",
    "ira.",
    "urr.",
    "aza.",
    "abe.",
  ],
  month_format_narrow => [
    "U",
    "O",
    "M",
    "A",
    "M",
    "E",
    "U",
    "A",
    "I",
    "U",
    "A",
    "A",
  ],
  month_format_wide => [
    "urtarrilak",
    "otsailak",
    "martxoak",
    "apirilak",
    "maiatzak",
    "ekainak",
    "uztailak",
    "abuztuak",
    "irailak",
    "urriak",
    "azaroak",
    "abenduak",
  ],
  month_stand_alone_abbreviated => [
    "urt.",
    "ots.",
    "mar.",
    "api.",
    "mai.",
    "eka.",
    "uzt.",
    "abu.",
    "ira.",
    "urr.",
    "aza.",
    "abe.",
  ],
  month_stand_alone_narrow => [
    "U",
    "O",
    "M",
    "A",
    "M",
    "E",
    "U",
    "A",
    "I",
    "U",
    "A",
    "A",
  ],
  month_stand_alone_wide => [
    "urtarrila",
    "otsaila",
    "martxoa",
    "apirila",
    "maiatza",
    "ekaina",
    "uztaila",
    "abuztua",
    "iraila",
    "urria",
    "azaroa",
    "abendua",
  ],
  name => "Basque Spain",
  native_language => "euskara",
  native_name => "euskara Espainia",
  native_script => undef,
  native_territory => "Espainia",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1Hh",
    "2Hh",
    "3Hh",
    "4Hh",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. hiruhilekoa",
    "2. hiruhilekoa",
    "3. hiruhilekoa",
    "4. hiruhilekoa",
  ],
  quarter_stand_alone_abbreviated => [
    "1Hh",
    "2Hh",
    "3Hh",
    "4Hh",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. hiruhilekoa",
    "2. hiruhilekoa",
    "3. hiruhilekoa",
    "4. hiruhilekoa",
  ],
  script => undef,
  territory => "Spain",
  time_format_full => "HH:mm:ss (zzzz)",
  time_format_long => "HH:mm:ss (z)",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 38,
}
