{
  am_pm_abbreviated => [
    "GH",
    "GD",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, MMM d, y G",
    GyMMMd => "MMM d, y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-one" => "'toddobaadka' W 'ee' MMMM",
    "MMMMW-count-other" => "'toddobaadka' W 'ee' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'toddobaadka' w 'ee' Y",
    "yw-count-other" => "'toddobaadka' w 'ee' Y",
  },
  code => "so-DJ",
  date_format_full => "EEEE, MMMM dd, y",
  date_format_long => "dd MMMM y",
  date_format_medium => "dd-MMM-y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Isn",
    "Tldo",
    "Arbc",
    "Khms",
    "Jmc",
    "Sbti",
    "Axd",
  ],
  day_format_narrow => [
    "I",
    "T",
    "A",
    "Kh",
    "J",
    "S",
    "A",
  ],
  day_format_wide => [
    "Isniin",
    "Talaado",
    "Arbaco",
    "Khamiis",
    "Jimco",
    "Sabti",
    "Axad",
  ],
  day_stand_alone_abbreviated => [
    "Isn",
    "Tldo",
    "Arbc",
    "Khms",
    "Jmc",
    "Sbti",
    "Axd",
  ],
  day_stand_alone_narrow => [
    "I",
    "T",
    "A",
    "Kh",
    "J",
    "S",
    "A",
  ],
  day_stand_alone_wide => [
    "Isniin",
    "Talaado",
    "Arbaco",
    "Khamiis",
    "Jimco",
    "Sabti",
    "Axad",
  ],
  era_abbreviated => [
    "CH",
    "CD",
  ],
  era_narrow => [
    "B",
    "A",
  ],
  era_wide => [
    "Ciise Hortii",
    "Ciise Dabadii",
  ],
  first_day_of_week => 6,
  glibc_date_1_format => "%a %b %e %r %Z %Y",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a %d %b %Y %r %Z",
  glibc_time_12_format => "%l:%M:%S %p",
  glibc_time_format => "%l:%M:%S %p",
  language => "Somali",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Abr",
    "May",
    "Jun",
    "Lul",
    "Ogs",
    "Seb",
    "Okt",
    "Nof",
    "Dis",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "L",
    "O",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Bisha Koobaad",
    "Bisha Labaad",
    "Bisha Saddexaad",
    "Bisha Afraad",
    "Bisha Shanaad",
    "Bisha Lixaad",
    "Bisha Todobaad",
    "Bisha Sideedaad",
    "Bisha Sagaalaad",
    "Bisha Tobnaad",
    "Bisha Kow iyo Tobnaad",
    "Bisha Laba iyo Tobnaad",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Abr",
    "May",
    "Jun",
    "Lul",
    "Ogs",
    "Seb",
    "Okt",
    "Nof",
    "Dis",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "L",
    "O",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Jannaayo",
    "Febraayo",
    "Maarso",
    "Abriil",
    "May",
    "Juun",
    "Luuliyo",
    "Ogost",
    "Sebtembar",
    "Oktoobar",
    "Nofembar",
    "Desembar",
  ],
  name => "Somali Djibouti",
  native_language => "Soomaali",
  native_name => "Soomaali Jabuuti",
  native_script => undef,
  native_territory => "Jabuuti",
  native_variant => undef,
  quarter_format_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Rubaca 1aad",
    "Rubaca 2aad",
    "Rubaca 3aad",
    "Rubaca 4aad",
  ],
  quarter_stand_alone_abbreviated => [
    "R1",
    "R2",
    "R3",
    "R4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Rubaca 1aad",
    "Rubaca 2aad",
    "Rubaca 3aad",
    "Rubaca 4aad",
  ],
  script => undef,
  territory => "Djibouti",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 38,
}
