{
  am_pm_abbreviated => [
    "ND",
    "LK",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "M",
    MEd => "MM-dd, E",
    MMM => "MMM",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "d/MM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "sg",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Bk2",
    "Bk3",
    "Bk4",
    "Bk5",
    "L\N{U+00e2}p",
    "L\N{U+00e2}y",
    "Bk1",
  ],
  day_format_narrow => [
    "S",
    "T",
    "S",
    "K",
    "P",
    "Y",
    "K",
  ],
  day_format_wide => [
    "B\N{U+00ef}kua-\N{U+00fb}se",
    "B\N{U+00ef}kua-pt\N{U+00e2}",
    "B\N{U+00ef}kua-us\N{U+00ef}\N{U+00f6}",
    "B\N{U+00ef}kua-ok\N{U+00fc}",
    "L\N{U+00e2}p\N{U+00f4}s\N{U+00f6}",
    "L\N{U+00e2}yenga",
    "Bikua-\N{U+00f4}ko",
  ],
  day_stand_alone_abbreviated => [
    "Bk2",
    "Bk3",
    "Bk4",
    "Bk5",
    "L\N{U+00e2}p",
    "L\N{U+00e2}y",
    "Bk1",
  ],
  day_stand_alone_narrow => [
    "S",
    "T",
    "S",
    "K",
    "P",
    "Y",
    "K",
  ],
  day_stand_alone_wide => [
    "B\N{U+00ef}kua-\N{U+00fb}se",
    "B\N{U+00ef}kua-pt\N{U+00e2}",
    "B\N{U+00ef}kua-us\N{U+00ef}\N{U+00f6}",
    "B\N{U+00ef}kua-ok\N{U+00fc}",
    "L\N{U+00e2}p\N{U+00f4}s\N{U+00f6}",
    "L\N{U+00e2}yenga",
    "Bikua-\N{U+00f4}ko",
  ],
  era_abbreviated => [
    "KnK",
    "NpK",
  ],
  era_narrow => [
    "KnK",
    "NpK",
  ],
  era_wide => [
    "K\N{U+00f4}zo na Kr\N{U+00ee}stu",
    "Na pek\N{U+00f4} t\N{U+00ee} Kr\N{U+00ee}stu",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Sango",
  month_format_abbreviated => [
    "Nye",
    "Ful",
    "Mb\N{U+00e4}",
    "Ngu",
    "B\N{U+00ea}l",
    "F\N{U+00f6}n",
    "Len",
    "K\N{U+00fc}k",
    "Mvu",
    "Ngb",
    "Nab",
    "Kak",
  ],
  month_format_narrow => [
    "N",
    "F",
    "M",
    "N",
    "B",
    "F",
    "L",
    "K",
    "M",
    "N",
    "N",
    "K",
  ],
  month_format_wide => [
    "Nyenye",
    "Fulund\N{U+00ef}gi",
    "Mb\N{U+00e4}ng\N{U+00fc}",
    "Ngub\N{U+00f9}e",
    "B\N{U+00ea}l\N{U+00e4}w\N{U+00fc}",
    "F\N{U+00f6}ndo",
    "Lengua",
    "K\N{U+00fc}k\N{U+00fc}r\N{U+00fc}",
    "Mvuka",
    "Ngberere",
    "Nab\N{U+00e4}nd\N{U+00fc}ru",
    "Kakauka",
  ],
  month_stand_alone_abbreviated => [
    "Nye",
    "Ful",
    "Mb\N{U+00e4}",
    "Ngu",
    "B\N{U+00ea}l",
    "F\N{U+00f6}n",
    "Len",
    "K\N{U+00fc}k",
    "Mvu",
    "Ngb",
    "Nab",
    "Kak",
  ],
  month_stand_alone_narrow => [
    "N",
    "F",
    "M",
    "N",
    "B",
    "F",
    "L",
    "K",
    "M",
    "N",
    "N",
    "K",
  ],
  month_stand_alone_wide => [
    "Nyenye",
    "Fulund\N{U+00ef}gi",
    "Mb\N{U+00e4}ng\N{U+00fc}",
    "Ngub\N{U+00f9}e",
    "B\N{U+00ea}l\N{U+00e4}w\N{U+00fc}",
    "F\N{U+00f6}ndo",
    "Lengua",
    "K\N{U+00fc}k\N{U+00fc}r\N{U+00fc}",
    "Mvuka",
    "Ngberere",
    "Nab\N{U+00e4}nd\N{U+00fc}ru",
    "Kakauka",
  ],
  name => "Sango",
  native_language => "S\N{U+00e4}ng\N{U+00f6}",
  native_name => "S\N{U+00e4}ng\N{U+00f6}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "F4\N{U+2013}1",
    "F4\N{U+2013}2",
    "F4\N{U+2013}3",
    "F4\N{U+2013}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "F\N{U+00e2}ngbis\N{U+00ef}\N{U+00f6} \N{U+00f4}ko",
    "F\N{U+00e2}ngbis\N{U+00ef}\N{U+00f6} \N{U+00fb}se",
    "F\N{U+00e2}ngbis\N{U+00ef}\N{U+00f6} ot\N{U+00e2}",
    "F\N{U+00e2}ngbis\N{U+00ef}\N{U+00f6} us\N{U+00ef}\N{U+00f6}",
  ],
  quarter_stand_alone_abbreviated => [
    "F4\N{U+2013}1",
    "F4\N{U+2013}2",
    "F4\N{U+2013}3",
    "F4\N{U+2013}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "F\N{U+00e2}ngbis\N{U+00ef}\N{U+00f6} \N{U+00f4}ko",
    "F\N{U+00e2}ngbis\N{U+00ef}\N{U+00f6} \N{U+00fb}se",
    "F\N{U+00e2}ngbis\N{U+00ef}\N{U+00f6} ot\N{U+00e2}",
    "F\N{U+00e2}ngbis\N{U+00ef}\N{U+00f6} us\N{U+00ef}\N{U+00f6}",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 38,
}
